@@ -1603,8 +1603,33 @@ def test_client_query_error(server, mocker):
         client.query(query.SECTORS)
 
 
-def test_client_get_status(server):
-    """Should raise HTTPError if there is a client error."""
+def test_client_query_invalid_response(server, mocker):
+    """Should raise ParseError if the response doesn't pass the expected parsing."""
+    html = """[
+       {
+           "Active": true,
+           "ActivePartial": false,
+           "Max": false,
+           "Activable": true,
+           "ActivablePartial": false,
+           "Id": 1,
+           "Index": 0,
+           "Element": 1,
+           "CommandId": 0,
+           "InProgress": false
+       }
+    ]"""
+    server.add(responses.POST, "https://example.com/api/areas", body=html, status=200)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    mocker.patch.object(client, "_get_descriptions")
+    # Test
+    with pytest.raises(ParseError):
+        client.query(query.SECTORS)
+
+
+def test_client_get_alerts_status(server):
+    """Should query a Elmo system to retrieve alerts status."""
     html = """
         {
             "StatusUid": 1,
@@ -1645,65 +1670,67 @@ def test_client_get_status(server):
             }
         }
     """
+
     server.add(responses.POST, "https://example.com/api/statusadv", body=html, status=200)
     client = ElmoClient(base_url="https://example.com", domain="domain")
     client._session_id = "test"
     # Test
-    result = client.get_status()
+    alerts = client.query(query.ALERTS)
     body = server.calls[0].request.body
     assert body == "sessionId=test"
-    assert result == {
-        "inputs_led": 2,
-        "anomalies_led": 1,
-        "alarm_led": 0,
-        "tamper_led": 0,
-        "has_anomaly": False,
-        "panel_tamper": 0,
-        "panel_no_power": 0,
-        "panel_low_battery": 0,
-        "gsm_anomaly": 0,
-        "gsm_low_balance": 0,
-        "pstn_anomaly": 0,
-        "system_test": 0,
-        "module_registration": 0,
-        "rf_interference": 0,
-        "input_failure": 0,
-        "input_alarm": 0,
-        "input_bypass": 0,
-        "input_low_battery": 0,
-        "input_no_supervision": 0,
-        "device_tamper": 0,
-        "device_failure": 0,
-        "device_no_power": 0,
-        "device_low_battery": 0,
-        "device_no_supervision": 0,
-        "device_system_block": 0,
+    # Expected output
+    assert alerts == {
+        0: {"name": "alarm_led", "status": 0},
+        1: {"name": "anomalies_led", "status": 1},
+        2: {"name": "device_failure", "status": 0},
+        3: {"name": "device_low_battery", "status": 0},
+        4: {"name": "device_no_power", "status": 0},
+        5: {"name": "device_no_supervision", "status": 0},
+        6: {"name": "device_system_block", "status": 0},
+        7: {"name": "device_tamper", "status": 0},
+        8: {"name": "gsm_anomaly", "status": 0},
+        9: {"name": "gsm_low_balance", "status": 0},
+        10: {"name": "has_anomaly", "status": False},
+        11: {"name": "input_alarm", "status": 0},
+        12: {"name": "input_bypass", "status": 0},
+        13: {"name": "input_failure", "status": 0},
+        14: {"name": "input_low_battery", "status": 0},
+        15: {"name": "input_no_supervision", "status": 0},
+        16: {"name": "inputs_led", "status": 2},
+        17: {"name": "module_registration", "status": 0},
+        18: {"name": "panel_low_battery", "status": 0},
+        19: {"name": "panel_no_power", "status": 0},
+        20: {"name": "panel_tamper", "status": 0},
+        21: {"name": "pstn_anomaly", "status": 0},
+        22: {"name": "rf_interference", "status": 0},
+        23: {"name": "system_test", "status": 0},
+        24: {"name": "tamper_led", "status": 0},
     }
 
 
-def test_client_get_status_http_error(server):
+def test_client_get_alerts_http_error(server):
     """Should raise HTTPError if there is a client error."""
     server.add(responses.POST, "https://example.com/api/statusadv", body="500 Error", status=500)
     client = ElmoClient(base_url="https://example.com", domain="domain")
     client._session_id = "test"
     # Test
     with pytest.raises(HTTPError):
-        client.get_status()
+        client.query(query.ALERTS)
     assert len(server.calls) == 1
 
 
-def test_client_get_status_invalid_json(server):
+def test_client_get_alerts_invalid_json(server):
     """Should raise ParseError if the response is unexpected."""
     server.add(responses.POST, "https://example.com/api/statusadv", body="Invalid JSON", status=200)
     client = ElmoClient(base_url="https://example.com", domain="domain")
     client._session_id = "test"
     # Test
     with pytest.raises(ParseError):
-        client.get_status()
+        client.query(query.ALERTS)
     assert len(server.calls) == 1
 
 
-def test_client_get_status_missing_data(server):
+def test_client_get_alerts_missing_data(server):
     """Should raise ParseError if some response data is missing."""
     html = """
         {
@@ -1727,5 +1754,5 @@ def test_client_get_status_missing_data(server):
     client._session_id = "test"
     # Test
     with pytest.raises(ParseError):
-        client.get_status()
+        client.query(query.ALERTS)
     assert len(server.calls) == 1
